@@ -20,8 +20,10 @@ platform = sys.platform
 
 try:
     modulo = import_module("." + platform, __package__)
-except Exception:
+except ModuleNotFoundError as exc:
     raise RuntimeError("Unsupported operating system: {}".format(platform))
+except Exception:
+    raise
 else:
     caller = getattr(modulo, "{}Notification".format(platform.title()))()
 
@@ -35,7 +37,7 @@ class Notification:
         message (str): The message body (optional).
         timeout (int): Notification length in milliseconds (optional).
         app_name (str): Caller app name. Defaults to 'notify-send'.
-        **kwargs: Additional arguments (optional).
+        kwargs: Additional arguments (optional).
     """
 
     def __init__(self, summary, message="", timeout=2000, **kwargs):
